aboutsummaryrefslogtreecommitdiffstats
path: root/xen/include/asm-ia64/vmx_vpd.h
diff options
context:
space:
mode:
Diffstat (limited to 'xen/include/asm-ia64/vmx_vpd.h')
-rw-r--r--xen/include/asm-ia64/vmx_vpd.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/xen/include/asm-ia64/vmx_vpd.h b/xen/include/asm-ia64/vmx_vpd.h
index fea1cc21ea..78149ba31f 100644
--- a/xen/include/asm-ia64/vmx_vpd.h
+++ b/xen/include/asm-ia64/vmx_vpd.h
@@ -113,9 +113,9 @@ typedef struct vpd {
void vmx_enter_scheduler(void);
//FIXME: Map for LID to exec_domain, Eddie
#define MAX_NUM_LPS (1UL<<16)
-extern struct exec_domain *lid_edt[MAX_NUM_LPS];
+extern struct vcpu *lid_edt[MAX_NUM_LPS];
struct arch_vmx_struct {
// struct virutal_platform_def vmx_platform;
@@ -113,9 +113,9 @@ typedef struct vpd {
void vmx_enter_scheduler(void);
-//FIXME: Map for LID to exec_domain, Eddie
+//FIXME: Map for LID to vcpu, Eddie
#define MAX_NUM_LPS (1UL<<16)